pub fn has_cycle<V>(q: &GraphQuery<V>) -> boolExpand description
Returns true if the graph contains a directed cycle.
Delegates to topological_sort.
pub fn has_cycle<V>(q: &GraphQuery<V>) -> boolReturns true if the graph contains a directed cycle.
Delegates to topological_sort.