pub fn has_path<V>(
q: &GraphQuery<V>,
weight: &TraversalWeight<V>,
from: &Pattern<V>,
to: &Pattern<V>,
) -> boolExpand description
Returns true if a path exists from from to to.
Delegates to shortest_path.
pub fn has_path<V>(
q: &GraphQuery<V>,
weight: &TraversalWeight<V>,
from: &Pattern<V>,
to: &Pattern<V>,
) -> boolReturns true if a path exists from from to to.
Delegates to shortest_path.