pub fn is_connected<V>(q: &GraphQuery<V>, weight: &TraversalWeight<V>) -> boolExpand description
Returns true if the entire graph is connected under weight.
An empty graph is vacuously connected (returns true).
pub fn is_connected<V>(q: &GraphQuery<V>, weight: &TraversalWeight<V>) -> boolReturns true if the entire graph is connected under weight.
An empty graph is vacuously connected (returns true).