GraphClass

Enum GraphClass 

pub enum GraphClass<Extra> {
    GNode,
    GRelationship,
    GAnnotation,
    GWalk,
    GOther(Extra),
}
The five structural categories a pattern can belong to.

Variants



GNode



GRelationship



GAnnotation



GWalk



GOther(Extra)

Implementations

Source

impl<Extra> GraphClass<Extra>

pub fn map_other<F, B>(self, f: F) -> GraphClass<B>
where F: FnOnce(Extra) -> B,

Maps a function over the Extra payload of GOther, leaving other variants unchanged.