from_pattern_graph

Function from_pattern_graph 

pub fn from_pattern_graph<Extra, V>(
    classifier: &GraphClassifier<Extra, V>,
    graph: &PatternGraph<Extra, V>,
) -> GraphView<Extra, V>
where Extra: Clone + 'static, V: GraphValue + Clone + 'static, V::Id: Clone + Eq + Hash + 'static,
Builds a GraphView from an existing PatternGraph and classifier.

The view’s query is built from the graph (shared ownership via Rc/Arc). view_elements contains every element in the graph classified by the given classifier, in an unspecified but stable order.