StandardGraph: ergonomic wrapper around PatternGraph<(), Subject>.
Provides zero-configuration graph construction and querying for the common case of building graph structures from atomic patterns (nodes, relationships, walks, annotations).
Structs
- Standard
Graph - A concrete, ergonomic graph type wrapping
PatternGraph<(), Subject>.