pub struct ValidationError {
pub message: String,
pub rule_violated: String,
pub location: Vec<String>,
}Expand description
Error type for pattern validation failures.
Provides detailed information about what rule was violated and where in the pattern structure the violation occurred.
Examples
use pattern_core::ValidationError;
let error = ValidationError {
message: "Pattern depth exceeds maximum".to_string(),
rule_violated: "max_depth".to_string(),
location: vec!["elements".to_string(), "0".to_string()],
};Fields
message: StringHuman-readable error message
rule_violated: StringName of violated rule (e.g., “max_depth”, “max_elements”)
location: Vec<String>Path to violating node in pattern structure