Module pattern_graph

Module pattern_graph 

PatternGraph: typed container for nodes, relationships, walks, and annotations.

Ported from Pattern.PatternGraph in the Haskell reference implementation. Patterns are routed into six typed collections by a GraphClassifier. Duplicate identities are resolved via ReconciliationPolicy.

Structs

PatternGraph
Materialized graph container with six typed collections, each keyed by identity.

Functions

from_pattern_graph
Wraps a PatternGraph in a GraphQuery<V>.
from_patterns
Builds a graph from an iterable of patterns using LastWriteWins.
from_patterns_with_policy
Builds a graph from an iterable of patterns using the given policy.
merge
Inserts one pattern using LastWriteWins policy.
merge_with_policy
Inserts one pattern using the given reconciliation policy.