pub struct Symbol(pub String);Expand description
Symbol identifier that uniquely identifies the subject.
A Symbol is a wrapper around a String that represents an identifier.
In gram notation, symbols appear before labels and properties.
Examples
use pattern_core::Symbol;
let symbol = Symbol("n".to_string());
assert_eq!(symbol.0, "n");Tuple Fields
0: StringTrait Implementations
Sourceimpl Ord for Symbol
impl Ord for Symbol
Sourceimpl PartialOrd for Symbol
impl PartialOrd for Symbol
impl Eq for Symbol
impl StructuralPartialEq for Symbol