Pattern reconciliation for normalizing duplicate identities.
Provides operations to reconcile patterns by resolving duplicate identities
and completing partial references. Ported from Pattern.Reconcile in the
Haskell reference implementation.
Structs
- Reconcile
Error - Error returned by
reconcilewhenStrictpolicy detects conflicts. - Subject
Merge Strategy - Strategy for merging Subject content.
Enums
- Element
Merge Strategy - Strategy for merging the children (elements) of a pattern.
- Label
Merge - Strategy for merging label sets.
- Property
Merge - Strategy for merging property maps.
- Reconciliation
Policy - Policy for resolving duplicate identities during reconciliation.
Traits
- HasIdentity
- Allows extracting a unique identifier from a value.
- Mergeable
- Allows merging two values according to a strategy.
- Refinable
- Allows checking if one value is a “partial” version of another.
Functions
- default_
subject_ merge_ strategy - Default merge strategy for Subjects.
- reconcile
- Normalizes a pattern by resolving duplicate identities according to the policy.